.. -*- coding: utf-8 -*-

.. _contents:

=====================================================
Référentiel SAEM - Guide de l'administrateur
=====================================================

.. toctree::
   :maxdepth: 2

   versions-config
   install
   ark
   skos
   eac
   seda
   web-services
   security
   client
   ChangeLog_fr